==> haskell-haddock-library-1.11.0-28-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-haddock-library.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 haddock-library
version:              1.11.0
visibility:           public
id:                   haddock-library-1.11.0-Jz4dAXi2GxeK7wNNBAEd96
key:                  haddock-library-1.11.0-Jz4dAXi2GxeK7wNNBAEd96
license:              BSD-2-Clause
maintainer:
    Alec Theriault <alec.theriault@gmail.com>, Alex Biehl <alexbiehl@gmail.com>, Simon Hengel <sol@typeful.net>, Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>

homepage:             http://www.haskell.org/haddock/
synopsis:             Library exposing some functionality of Haddock.
description:
    Haddock is a documentation-generation tool for Haskell
    libraries. These modules expose some
    functionality of it without pulling in the GHC
    dependency. Please note that the API is likely
    to change so be sure to specify upper bounds in
    your projects. For interacting with Haddock
    itself, see the [haddock package](https://hackage.haskell.org/package/haddock).

category:             Documentation
abi:                  176e09a4ffcdd146bb841a53013acd28
exposed:              True
exposed-modules:
    Documentation.Haddock.Doc Documentation.Haddock.Markup
    Documentation.Haddock.Parser Documentation.Haddock.Types

hidden-modules:
    CompatPrelude Documentation.Haddock.Parser.Util
    Documentation.Haddock.Parser.Monad
    Documentation.Haddock.Parser.Identifier

import-dirs:          /usr/lib/ghc-9.2.8/site-local/haddock-library-1.11.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/haddock-library-1.11.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-haddock-library
hs-libraries:         HShaddock-library-1.11.0-Jz4dAXi2GxeK7wNNBAEd96
depends:
    base-4.16.4.0 containers-0.6.5.1 parsec-3.1.15.0 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-haddock-library/html/haddock-library.haddock

haddock-html:         /usr/share/doc/haskell-haddock-library/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-haddock-library-1.11.0-82.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-haddock-library.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haddock-library
version:              1.11.0
visibility:           public
id:                   haddock-library-1.11.0-IhwAfweNEn1GXtdJUnXt94
key:                  haddock-library-1.11.0-IhwAfweNEn1GXtdJUnXt94
license:              BSD-2-Clause
maintainer:
    Alec Theriault <alec.theriault@gmail.com>, Alex Biehl <alexbiehl@gmail.com>, Simon Hengel <sol@typeful.net>, Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>

homepage:             http://www.haskell.org/haddock/
synopsis:             Library exposing some functionality of Haddock.
description:
    Haddock is a documentation-generation tool for Haskell
    libraries. These modules expose some
    functionality of it without pulling in the GHC
    dependency. Please note that the API is likely
    to change so be sure to specify upper bounds in
    your projects. For interacting with Haddock
    itself, see the [haddock package](https://hackage.haskell.org/package/haddock).

category:             Documentation
abi:                  6cf2df2c2b15e2b20f43bc56df2060c2
exposed:              True
exposed-modules:
    Documentation.Haddock.Doc Documentation.Haddock.Markup
    Documentation.Haddock.Parser Documentation.Haddock.Types

hidden-modules:
    CompatPrelude Documentation.Haddock.Parser.Util
    Documentation.Haddock.Parser.Monad
    Documentation.Haddock.Parser.Identifier

import-dirs:          /usr/lib/ghc-9.4.8/site-local/haddock-library-1.11.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/haddock-library-1.11.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/haddock-library-1.11.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-haddock-library
hs-libraries:         HShaddock-library-1.11.0-IhwAfweNEn1GXtdJUnXt94
depends:
    base-4.17.2.1 containers-0.6.7 parsec-3.1.16.1 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-haddock-library/html/haddock-library.haddock

haddock-html:         /usr/share/doc/haskell-haddock-library/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
